==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/cconnection.h <==
/***************************************************************************
                          cconnection.h  -  handles connections
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Po Jul 22 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CCONNECTION_H
#define CCONNECTION_H

#include <qobject.h>
#include <qstringlist.h>

#include "csessionbase.h"

class cConnectionInfo;
class cConnPrefs;

class dlgProfileSettings;

class QTimer;

/*
Current status of cConnection class (Aug 13, 2002):
 - all required features implemented
 - new features may still be added
 - code has been tested and it seems to work
 - TODO: currently sending login & password is done by waiting for some
     server output. This may not be good with slow/lagging servers. Something
     better should be implemented...
*/

/**
This class handles connecting, disconnecting, calls load/save
of connection settings and related things.
  *@author Tomas Mecir
  */

class cConnection : public QObject, public cSessionBase {
   Q_OBJECT
public: 
  cConnection ();
  ~cConnection ();
  void establishConnection (cConnectionInfo *cci, bool sendNothing = false);
  void establishQuickConnection (cConnectionInfo *cci);
  bool isConnected ();
  void disconnect ();
  void reconnect ();
  cConnectionInfo *getConnectionInfo () { return ci; };
  cConnPrefs *getConnPrefs () { return cp; };
  QString getCaption () { return caption; };
  /** call enable/disable menu items in KMuddy as needed */
  void updateMenus ();
  void setConnectionClosed (bool canCloseTab) { connclosed = true; canCT = canCloseTab; };
  void unsetConnectionClosed () { connclosed = false; canCT = false; };
  bool connectionClosed () { return connclosed; };
public slots:
  void showConnPrefsDialog ();
  bool handleDisconnect ();
  /** shows Aliases dialog box */
  void handleAliasesDialog ();
  /** shows Triggers dialog box */
  void handleTriggersDialog ();
  /** shows Actions dialog box */
  void handleActionsDialog ();
  /** shows Scripts dialog box */
  void handleScriptsDialog ();
  /** shows Timers dialog box */
  void handleTimersDialog ();
  /** shows Macro keys dialog box */
  void handleShortcutsDialog ();
  /** shows Variables dialog box */
  void handleVariablesDialog ();
  /** shows Variable triggers dialog box */
  void handleVarTrigsDialog ();
  /** shows Status Variables dialog box */
  void handleStatusVarsDialog ();
  /** shows Gauges dialog box */
  void handleGaugesDialog ();
  /** shows Output Windows dialog box */
  void handleWindowsDialog ();
  /** shows Tick timer dialog box */
  void handleTickTimerDialog ();
  /** enable/disable alias processing */
  void switchAliases (bool val);
  /** enable/disable trigger processing */
  void switchTriggers (bool val);
  /** enable/disable timer processing */
  void switchTimers (bool val);
  /** enable/disable macro key processing */
  void switchShortcuts (bool val);
protected slots:
  /** attached to timeout() of connecting timer*/
  void sendLoginAndPassword ();
  /** called when user presses Ok or Apply in MUD Settings dialog */
  void getSettingsFromDialog ();
  /** used to save settings periodically*/
  void saverTimeout ();
protected:
  /** puts profile settings to MUD Settings dialog */
  void putSettingsToDialog ();

  cConnectionInfo *ci;
  cConnPrefs *cp;

  QString caption;
  
  QTimer *connecting;
  QTimer *saver;

  dlgProfileSettings *sdlg;

  bool destroying;

  bool connclosed;
  bool canCT;
  
  //login sequence and its iterator
  QStringList loginSeq;
  QStringList::iterator seqIter;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/cconnection.h <==
/***************************************************************************
                          cconnection.h  -  handles connections
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Po Jul 22 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CCONNECTION_H
#define CCONNECTION_H

#include <qobject.h>
#include <qstringlist.h>

#include "cactionbase.h"

struct cConnectionPrivate;
class cConnectionInfo;
class cSaveableList;

/**
This class handles connecting, disconnecting, calls load/save
of connection settings and related things.
  *@author Tomas Mecir
  */

class cConnection : public QObject, public cActionBase {
   Q_OBJECT
public: 
  cConnection (int sess);
  ~cConnection ();
  void establishConnection (cConnectionInfo *cci, bool sendNothing = false);
  void establishQuickConnection (cConnectionInfo *cci);
  bool isConnected ();
  void disconnect ();
  void reconnect ();
  cConnectionInfo *getConnectionInfo ();
  QString getCaption ();
  /** call enable/disable menu items in KMuddy as needed */
  void updateMenus ();
  void setConnectionClosed (bool canCloseTab);
  void unsetConnectionClosed ();
  bool connectionClosed ();
  
  void addCommand (const QString &command);
  void sendCommands ();
  int sentCommands ();

  cSaveableList *getList (const QString &name);
  
  virtual void eventHandler (QString event, int session);
  virtual void eventHandler (QString event, int session,
      QString &par1, const QString &);
  virtual QString actionHandler (QString action, int session, QString &par1, const QString &);
  virtual QString actionHandler (QString action, int session);

public slots:
  void showConnPrefsDialog ();
  bool handleDisconnect ();
  /** shows Aliases dialog box */
  void handleAliasesDialog ();
  /** shows Triggers dialog box */
  void handleTriggersDialog ();
  /** shows Actions dialog box */
  void handleActionsDialog ();
  /** shows Timers dialog box */
  void handleTimersDialog ();
  /** shows Macro keys dialog box */
  void handleShortcutsDialog ();
  /** shows Variables dialog box */
  void handleVariablesDialog ();
  /** shows Variable triggers dialog box */
  void handleVarTrigsDialog ();
  /** shows Status Variables dialog box */
  void handleStatusVarsDialog ();
  /** shows Gauges dialog box */
  void handleGaugesDialog ();
  /** shows Output Windows dialog box */
  void handleWindowsDialog ();
  /** shows Tick timer dialog box */
  void handleTickTimerDialog ();
  /** enable/disable alias processing */
  void switchAliases (bool val);
  /** enable/disable trigger processing */
  void switchTriggers (bool val);
  /** enable/disable timer processing */
  void switchTimers (bool val);
  /** enable/disable macro key processing */
  void switchShortcuts (bool val);
protected slots:
  /** attached to timeout() of connecting timer*/
  void sendLoginAndPassword ();
  /** called when user presses Ok or Apply in MUD Settings dialog */
  void getSettingsFromDialog ();
  /** used to save settings periodically*/
  void saverTimeout ();
  /** save settings */
  void save ();
protected:
  /** puts profile settings to MUD Settings dialog */
  void putSettingsToDialog ();

  /** load all the lists */
  void loadLists ();
  
  /** d-pointer for this class */
  cConnectionPrivate *d;
};

#endif
